@@ -1,5 +1,5 @@
 import os
-from typing import List, Type, Union
+from typing import List
 
 from jivago.config.abstract_context import AbstractContext
 from jivago.config.exception_mapper_binder import ExceptionMapperBinder
@@ -14,10 +14,12 @@ from jivago.event.config.reflective_event_bus_initializer import ReflectiveEvent
 from jivago.event.config.runnable_event_handler_binder import RunnableEventHandlerBinder
 from jivago.event.event_bus import EventBus
 from jivago.event.synchronous_event_bus import SynchronousEventBus
-from jivago.inject.annotation import Component, Singleton
+from jivago.inject.annotation import Component, Singleton, RequestScoped
 from jivago.inject.annoted_class_binder import AnnotatedClassBinder
 from jivago.inject.provider_binder import ProviderBinder
-from jivago.inject.scope_cache import ScopeCache
+from jivago.inject.scope.request_scope_cache import RequestScopeCache
+from jivago.inject.scope.scope_cache import ScopeCache
+from jivago.inject.scope.singleton_scope_cache import SingletonScopeCache
 from jivago.lang.annotations import Override, BackgroundWorker
 from jivago.lang.registry import Registry
 from jivago.lang.stream import Stream
@@ -26,18 +28,14 @@ from jivago.scheduling.task_scheduler import TaskScheduler
 from jivago.serialization.deserializer import Deserializer
 from jivago.serialization.object_mapper import ObjectMapper
 from jivago.serialization.serializer import Serializer
-from jivago.templating.template_filter import TemplateFilter
 from jivago.templating.view_template_repository import ViewTemplateRepository
 from jivago.wsgi.annotations import Resource
-from jivago.wsgi.filter.filter import Filter
+from jivago.wsgi.filter.system_filters.banner_filter import BannerFilter, DummyBannerFilter
 from jivago.wsgi.filter.system_filters.body_serialization_filter import BodySerializationFilter
-from jivago.wsgi.filter.system_filters.error_handling.application_exception_filter import ApplicationExceptionFilter
-from jivago.wsgi.filter.system_filters.error_handling.unknown_exception_filter import UnknownExceptionFilter
-from jivago.wsgi.filter.system_filters.jivago_banner_filter import JivagoBannerFilter
-from jivago.wsgi.request.http_form_deserialization_filter import HttpFormDeserializationFilter
+from jivago.wsgi.filter.system_filters.default_filters import JIVAGO_DEFAULT_FILTERS
 from jivago.wsgi.request.http_status_code_resolver import HttpStatusCodeResolver
-from jivago.wsgi.request.json_serialization_filter import JsonSerializationFilter
 from jivago.wsgi.request.partial_content_handler import PartialContentHandler
+from jivago.wsgi.routing.cors.cors_headers_injection_filter import CorsHeadersInjectionFilter
 from jivago.wsgi.routing.routing_rule import RoutingRule
 from jivago.wsgi.routing.table.auto_discovering_routing_table import AutoDiscoveringRoutingTable
 
@@ -53,6 +51,7 @@ class ProductionJivagoContext(AbstractContext):
 
     @Override
     def configure_service_locator(self):
+        # Automatic binding of user-defined components
         AnnotatedClassBinder(self.root_package_name, self.registry, Component).bind(self.serviceLocator)
         AnnotatedClassBinder(self.root_package_name, self.registry, Resource).bind(self.serviceLocator)
         AnnotatedClassBinder(self.root_package_name, self.registry, BackgroundWorker).bind(self.serviceLocator)
@@ -62,22 +61,32 @@ class ProductionJivagoContext(AbstractContext):
         AnnotatedClassBinder(self.root_package_name, self.registry, PostInit).bind(self.serviceLocator)
         AnnotatedClassBinder(self.root_package_name, self.registry, EventHandlerClass).bind(self.serviceLocator)
         AnnotatedClassBinder(self.root_package_name, self.registry, RequestFilter).bind(self.serviceLocator)
-
+        RunnableEventHandlerBinder(self.root_package_name, self.registry).bind(self.serviceLocator)
+        ExceptionMapperBinder().bind(self.serviceLocator)
         ProviderBinder(self.root_package_name, self.registry).bind(self.serviceLocator)
-        for scope in self.scopes():
-            scoped_classes = Stream(self.registry.get_annotated_in_package(scope, self.root_package_name)).map(
-                lambda registration: registration.registered).toList()
-            cache = ScopeCache(scope, scoped_classes)
+
+        # Component scope management
+        for scope in [Singleton, BackgroundWorker]:
+            scoped_classes = Stream(self.registry.get_annotated_in_package(scope, self.root_package_name)) \
+                .map(lambda registration: registration.registered) \
+                .toList()
+            cache = SingletonScopeCache(str(scope), scoped_classes)
             self.serviceLocator.register_scope(cache)
 
-        Stream(self.get_default_filters()).forEach(lambda f: self.serviceLocator.bind(f, f))
+        request_scope_cache = RequestScopeCache(
+            Stream(self.registry.get_annotated_in_package(RequestScoped, self.root_package_name))
+                .map(lambda registration: registration.registered)
+                .toList())
+        self.serviceLocator.register_scope(request_scope_cache)
 
-        # TODO better way to handle Jivago Dependencies
+        # Jivago dependencies
+        Stream(JIVAGO_DEFAULT_FILTERS).forEach(lambda f: self.serviceLocator.bind(f, f))
         self.serviceLocator.bind(Registry, Registry.INSTANCE)
         self.serviceLocator.bind(TaskScheduler, TaskScheduler(self.serviceLocator))
         self.serviceLocator.bind(Deserializer, Deserializer(Registry.INSTANCE))
         self.serviceLocator.bind(Serializer, Serializer())
         self.serviceLocator.bind(ViewTemplateRepository, ViewTemplateRepository(self.get_views_folder_path()))
+        self.serviceLocator.bind(CorsHeadersInjectionFilter, CorsHeadersInjectionFilter)
         self.serviceLocator.bind(BodySerializationFilter, BodySerializationFilter)
         self.serviceLocator.bind(PartialContentHandler, PartialContentHandler)
         self.serviceLocator.bind(HttpStatusCodeResolver, HttpStatusCodeResolver)
@@ -85,13 +94,10 @@ class ProductionJivagoContext(AbstractContext):
         self.serviceLocator.bind(EventBus, self.create_event_bus())
         self.serviceLocator.bind(SynchronousEventBus, self.serviceLocator.get(EventBus))
         self.serviceLocator.bind(AsyncEventBus, AsyncEventBus(self.serviceLocator.get(EventBus)))
+        self.serviceLocator.bind(RequestScopeCache, request_scope_cache)
 
-        RunnableEventHandlerBinder(self.root_package_name, self.registry).bind(self.service_locator())
-
-        ExceptionMapperBinder().bind(self.serviceLocator)
-
-    def scopes(self) -> List[type]:
-        return [Singleton, BackgroundWorker]
+        if not self.banner:
+            self.serviceLocator.bind(BannerFilter, DummyBannerFilter)
 
     @Override
     def get_views_folder_path(self) -> str:
@@ -104,19 +110,10 @@ class ProductionJivagoContext(AbstractContext):
     @Override
     def create_router_config(self) -> RouterBuilder:
         return RouterBuilder() \
-            .add_rule(FilteringRule("*", self.get_default_filters())) \
+            .add_rule(FilteringRule("*", JIVAGO_DEFAULT_FILTERS)) \
             .add_rule(AutoDiscoveringFilteringRule("*", self.registry, self.root_package_name)) \
             .add_rule(RoutingRule("/", AutoDiscoveringRoutingTable(self.registry, self.root_package_name)))
 
-    def get_default_filters(self) -> List[Union[Filter, Type[Filter]]]:
-        default_filters = [UnknownExceptionFilter, TemplateFilter, JsonSerializationFilter,
-                           HttpFormDeserializationFilter,
-                           BodySerializationFilter, ApplicationExceptionFilter]
-        if self.banner:
-            default_filters.append(JivagoBannerFilter)
-
-        return default_filters
-
     def create_event_bus(self) -> EventBus:
         return ReflectiveEventBusInitializer(self.service_locator(), self.registry,
                                              self.root_package_name).create_message_bus()
