@@ -6,5 +6,5 @@ class MessageDispatcher(object):
     def can_handle(self, message_name: str) -> bool:
         return self.message_name == message_name
 
-    async def handle(self, payload: object):
+    def handle(self, payload: object):
         raise NotImplementedError
