@@ -1,13 +1,16 @@
-from typing import Callable, Optional
+from typing import Callable, Optional, TypeVar, Type, Union, List
 
 from jivago.inject import typing_meta_helper
 from jivago.inject.exception.instantiation_exception import InstantiationException
 from jivago.inject.exception.non_injectable_constructor_exception import NonInjectableConstructorException
-from jivago.inject.scope_cache import ScopeCache
+from jivago.inject.scope.scope_cache import ScopeCache
 from jivago.lang.annotations import Inject
 from jivago.lang.registry import Registry
 from jivago.lang.stream import Stream
 
+T = TypeVar("T")
+S = TypeVar("S")
+
 
 class ServiceLocator(object):
     def __init__(self, registry=Registry()):
@@ -17,7 +20,7 @@ class ServiceLocator(object):
         self.providers = {}
         self.scopeCaches = []
 
-    def bind(self, interface, implementation):
+    def bind(self, interface: Type[T], implementation: Union[Type[T], Type[S], T, Callable[..., T]]):
         if self.__is_provider_function(implementation):
             self.providers[interface] = implementation
         elif isinstance(implementation, type):
@@ -28,7 +31,7 @@ class ServiceLocator(object):
     def register_scope(self, scope_cache: ScopeCache):
         self.scopeCaches.append(scope_cache)
 
-    def get(self, interface: type):
+    def get(self, interface: Type[T]) -> T:
         if interface in self.literals.keys():
             return self.literals[interface]
         if typing_meta_helper.is_typing_meta_collection(interface):
@@ -43,7 +46,7 @@ class ServiceLocator(object):
         if scope is not None and scope.is_stored(stored_component):
             return scope.get(stored_component)
         instance = None
-        
+
         if interface in self.providers.keys():
             instance = self.__inject_function(self.providers[interface])
         else:
@@ -54,7 +57,7 @@ class ServiceLocator(object):
             scope.store(stored_component, instance)
         return instance
 
-    def get_all(self, clazz: type):
+    def get_all(self, clazz: Type[T]) -> List[T]:
         return Stream(self.literals.keys(), self.components.keys(), self.providers.keys()).filter(
             lambda k: issubclass(k, clazz)).map(lambda k: self.get(k)).toList()
 
@@ -75,6 +78,7 @@ class ServiceLocator(object):
                     break
                 parameter = parameter_types[name]
                 parameters.append(self.get(parameter))
+        # TODO this AttributeError catch block is too broad, and sometimes hides user errors. - keotl - 2020-09-13
         except AttributeError:
             pass
         return provider_method(*parameters)
