@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, timezone
 
 from croniter import croniter
 
@@ -10,7 +10,7 @@ class CronSchedule(Schedule):
 
     def __init__(self, cron_string: str, start_time: datetime):
         if start_time:
-            self.iterator = croniter(cron_string, start_time=start_time.timestamp())
+            self.iterator = croniter(cron_string, start_time=start_time.astimezone(timezone.utc))
         else:
             self.iterator = croniter(cron_string)
 
