@@ -1,4 +1,4 @@
-from jivago.inject.registry import ParametrizedAnnotation
+from jivago.lang.registry import ParametrizedAnnotation
 
 
 @ParametrizedAnnotation
@@ -9,4 +9,3 @@ def Resource(value: str):
 @ParametrizedAnnotation
 def Path(value: str):
     return lambda x: x
-
