@@ -2,13 +2,14 @@ import logging
 import traceback
 
 from jivago.lang.annotations import Override
-from jivago.wsgi.filter.filter import Filter
 from jivago.wsgi.filter.filter_chain import FilterChain
+from jivago.wsgi.filter.system_filters.error_handling.unknown_exception_filter import UnknownExceptionFilter
 from jivago.wsgi.request.request import Request
 from jivago.wsgi.request.response import Response
 
 
-class DebugExceptionFilter(Filter):
+class DebugExceptionFilter(UnknownExceptionFilter):
+    """Sends a stacktrace in the response body to help debugging. Enabled by default when using 'DebugJivagoContext'."""
     LOGGER = logging.getLogger("DebugExceptionFilter")
 
     @Override
